//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgs](index.md)/[shantenResult](shanten-result.md)

# shantenResult

[common]\
val [shantenResult](shanten-result.md): [CommonShantenResult](../../mahjongutils.shanten/-common-shanten-result/index.md)&lt;*&gt;? = null

#### Parameters

common

| | |
|---|---|
| shantenResult | 向听分析结果 |
